#
# spec file for package libass
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 4

Name:           libass
Version:        0.10.1
Release:        1.1
License:        ISC
Summary:        Portable Library for SSA/ASS Subtitles Rendering
Url:            http://code.google.com/p/libass/
Group:          System/Libraries
Source:         http://libass.googlecode.com/files/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  pkg-config
BuildRequires:  enca-devel
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  fribidi-devel

%description
libass is a portable subtitle renderer for the ASS/SSA
 (Advanced Substation Alpha/Substation Alpha) subtitle
format. It is mostly compatible with VSFilter.

%package -n libass%{soname}
Summary:        Portable Library for SSA/ASS Subtitles Rendering
Group:          Development/Libraries/C and C++

%description -n libass%{soname}
libass is a portable subtitle renderer for the ASS/SSA
 (Advanced Substation Alpha/Substation Alpha) subtitle
format. It is mostly compatible with VSFilter.

%package devel
Summary:        Portable Library for SSA/ASS Subtitles Rendering
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libass%{soname} = %{version}

%description devel
This package is needed if you want to develop / compile against libASS.

%prep
%setup -q

%build
%configure --disable-silent-rules \
	--disable-static
make %{?_smp_mflags}

%install
make DESTDIR='%{buildroot}' install
rm -f %{buildroot}%{_libdir}/*.la

%check
make check

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post -n libass%{soname} -p /sbin/ldconfig

%postun -n libass%{soname} -p /sbin/ldconfig

%files -n libass%{soname}
%defattr(-, root, root)
%{_libdir}/*.so.%{soname}
%{_libdir}/*.so.%{soname}.*

%files devel
%defattr(-, root, root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Jan  7 2013 Manfred.Tremmel@iiv.de
- Update to version 0.10.1
  + Fix letter spacing
  + Add \rSTYLENAME syntax support (GC #43)
  + Fix border generation and border style reset (GC #56)
  + Fix various issues with bug-for-bug compatibility of
    transformations (\fax, \fay, etc.) to VSFilter (GC #46, GC #42)
  + Fix drawing parsing (GC #47)
  + Various fixes to shaper (GC #54, GC #55, GC#59)
  + Fix change detection
  + Add ass_set_line_position API to set a vertical subtitle offset
  + Fix scaling of drawing baseline offset (\pbo) values
  + Fix skipping of zero-width characters for FriBiDi shaper
  + Use LTR text base direction by default, similar to VSFilter
* Sat Oct 29 2011 reddwarf@opensuse.org
- Update to version 0.10.0
  + Bidirectional layout and Arabic shaping via FriBidi (GC #13)
  + Add API for shaper configuration
  + Add support for `Language' Script Info property, this can be
    used for hinting the text language
  + Vertical layout improvements
  * Use `vert' and `vkna' OpenType features for vertical glyph
    variants
  * Position rotated glyphs onto baseline
  + Parse font encoding property for base text direction hinting
  + Refactor cache system
  + Use generic outlines in place of FreeType glyphs
  + Direct outline bitmap rendering
  + Fix whitespace trimming (GC #35)
  + Do not render border if there's no shadow or glyph (GC #29)
  + Adjust spacing after a italic to non-italic style change (GC #37)
  + Fix fade timing
  + Fix x positioning with borders (GC #27)
- Use pkgconfig() BuildRequires
- Parameterize the soname number
* Thu Jun 30 2011 dimstar@opensuse.org
- Update to version 0.9.12:
  + Switch to permissive (ISC) license
  + Support \fs+ and \fs- syntax for modifying font size
  + Fix word-wrapping
  + Improved charmap fallback matching
  + Handle a few more VSFilter quirks correctly
  + Add a sensible default style
  + Fix compilation against libpng 1.5
- Add xz BuildRequires, as the new tarballs are xz compressed
- Change License tag from GPLv2+ to ISC, as upstream changed to
  this license.
- Do not use source service, as Factory is moving away from it in
  favor of a different implementation to verify authenticity of
  tarballs. Consequently add a valid URL as Source.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- updated description to official description (fix for RPMLINT warning)
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- fix -devel package dependencies
* Fri Sep 10 2010 reddwarf@opensuse.org
- Update to version 0.9.11
  * Fix serious memory leaks
  * Reduce frame/drawing initialization overhead
  * Basic (incorrect, but working) support for @font vertical text layout
  * Fix multiple faces per font attachment
  * charmap selection fixes
  * Add ass_flush_events API function
  * Improve fullname font matching
  * Better PAR correction if text transforms are used
  * Calculate drawing bounding box like VSFilter
  * Performance improvements
  * Cache vector clip masks
  * Avoid unnecessary glyph copies
  * Various rendering fixes
  * Parse numbers in a locale-independent way
  * Remove support for freetype < 2.2.1, fontconfig < 2.4.1; this especially
  means libass will not extract fonts into the file system anymore
  * Disable script file size limit
  * Match fonts against the full name ("name for humans")
  * Reset clip mode after \iclip
  * Improve VSFilter compatibility
  * Update API documentation
  * A couple of smaller fixes and cleanups
  * Support \q override tag
  * Support wrap style 1 (i.e. wrap, but do not equalize line lengths)
  * Support border style 3 (opaque box)
  * Use the event bounding box (instead of vertical position and height) for
  collision detection
  * Embold glyphs if no bold variant is available, but was requested
  * Modify \fax to be similar to VSFilter
  * Trim spaces after line wrapping
  * Fix border/shadow overlap combining in some cases
  * Disable kerning by default.  Use "Kerning=yes" style override or
  "Kerning: yes" in [Script Info] to enable it
  * Slight bitmap handling optimizations
  * Various bugfixes
* Sat Sep 26 2009 cmorve69@yahoo.es
- Remove unneeded autoreconf
- Correct license tag
- Make build more verbose so checking tools can do its work
* Tue Aug 11 2009 sbrabec@suse.cz
- New SuSE package, version 0.9.7.
- Name and split according to shared library packaging policy.
* Sat Mar 21 2009 cmorve69@yahoo.es
- and now to the OBS
- update to 0.9.6
* Thu Sep 18 2008 detlef@links2linux.de
- initial build for PackMan to be compatible with vlc-repo
* Tue Aug 26 2008 dominique-rpm@leuenberger.net
- Initial package for version 0.9.5
